@@ -38,14 +38,16 @@ int esd_audio_open()
     if ((afd = open(device, mode, 0)) == -1)
     {   /* Opening device failed */
         perror(device);
-        return( -1 );
+        return( -2 );
     }
 
     /* TODO: check that this is allowable */
     /* set for full duplex operation, if recording */
+#if defined(SNDCTL_DSP_SETDUPLEX)
     if ( (esd_audio_format & ESD_MASK_FUNC) == ESD_RECORD ) {
         ioctl( afd, SNDCTL_DSP_SETDUPLEX, 0 );
     }
+#endif
 
     /* set the sound driver fragment size and number */
 #if !defined(__powerpc__) /* does not exist on powerpc */
@@ -68,7 +70,7 @@ int esd_audio_open()
 #endif /* #if !defined(__powerpc__) */
 
     /* set the sound driver audio format for playback */
-#if defined(__powerpc__)
+#if defined(__powerpc__) || defined(__sparc__)
     value = test = ( (esd_audio_format & ESD_MASK_BITS) == ESD_BITS16 )
         ? /* 16 bit */ AFMT_S16_NE : /* 8 bit */ AFMT_U8;
 #else /* #if !defined(__powerpc__) */
